@@ -1,7 +1,7 @@
 package RDF::DOAP::Change;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.013_02';
+our $VERSION   = 0.001;
 
 use Moose;
 extends qw(RDF::DOAP::Resource);
@@ -9,7 +9,7 @@ extends qw(RDF::DOAP::Resource);
 use RDF::DOAP::Person;
 use RDF::DOAP::Types -types;
 use RDF::DOAP::Utils -traits;
-use List::Util qw(uniq);
+use List::MoreUtils qw(uniq);
 use Text::Wrap qw(wrap);
 
 use RDF::Trine::Namespace qw(rdf rdfs owl xsd);
@@ -72,18 +72,9 @@ sub changelog_entry
 sub changelog_lines
 {
 	my $self = shift;
-	my ($notype) = @_;
+	my @type = sort map $_->uri =~ m{(\w+)$}, @{ $self->rdf_type };
 	
-	my @lines;
-	if ($notype)
-	{
-		@lines = $self->label;
-	}
-	else
-	{
-		my @type = sort map $_->uri =~ m{(\w+)$}, @{ $self->rdf_type };
-		@lines = "(@type) " . $self->label;
-	}
+	my @lines = "(@type) " . $self->label;
 	
 	for my $person (uniq sort @{$self->blame||[]}, @{$self->thanks||[]})
 	{
