@@ -1,11 +1,11 @@
 package RDF::DOAP::Resource;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.013_02';
+our $VERSION   = 0.001;
 
 use Moose;
 
-use Carp;
+use Types::Standard -types;
 use RDF::DOAP::Types -types;
 use RDF::DOAP::Utils -traits;
 use Scalar::Util qw( weaken refaddr );
@@ -106,30 +106,6 @@ sub rdf_load
 	return $self;
 }
 
-sub rdf_get
-{
-	my $self = shift;
-	croak "This object cannot rdf_get; stopped"
-		unless $self->has_rdf_model && $self->has_rdf_about;
-	
-	my @values = $self->rdf_model->objects_for_predicate_list($self->rdf_about, @_);
-	wantarray ? @values : $values[0];
-}
-
-sub rdf_get_literal
-{
-	my $self = shift;
-	my @values = grep $_->is_literal, $self->rdf_get(@_);
-	wantarray ? @values : $values[0];
-}
-
-sub rdf_get_uri
-{
-	my $self = shift;
-	my @values = grep $_->is_resource, $self->rdf_get(@_);
-	wantarray ? @values : $values[0];
-}
-
 sub TO_JSON
 {
 	my $self = shift;
@@ -161,14 +137,4 @@ sub dump_json
 	);
 }
 
-sub isa
-{
-	my $self = shift;
-	
-	return grep($_[0]->equal($_), @{$self->rdf_type})
-		if Identifier->check(@_);
-	
-	$self->SUPER::isa(@_);
-}
-
 1;
