@@ -1,10 +1,7 @@
 package RDF::DOAP::Types;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.013_02';
-
-use strict;
-use warnings;
+our $VERSION   = 0.001;
 
 use Type::Utils -all;
 use Type::Library -base;
