@@ -1,14 +1,14 @@
 package RDF::DOAP::Utils;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.013_02';
+our $VERSION   = 0.001;
 
 use strict;
 use warnings;
 
 use RDF::DOAP::Types -types;
 use match::simple 'match';
-use List::Util 'uniq';
+use List::MoreUtils 'uniq';
 
 use MooseX::AttributeTags (
 	WithURI   => [
@@ -20,8 +20,8 @@ use MooseX::AttributeTags (
 	],
 );
 
-use Exporter::Tiny ();
-our @ISA         = qw( Exporter::Tiny );
+use Exporter::TypeTiny;
+our @ISA         = qw(Exporter::TypeTiny);
 our @EXPORT_OK   = qw( WithURI Gathering );
 our %EXPORT_TAGS = (
 	traits => [qw( WithURI Gathering )]
@@ -37,7 +37,7 @@ sub _gather_objects
 	if (ArrayRef->check($self))
 	{
 		return uniq(
-			grep defined, map _gather_objects($_, $relation), grep defined, @$self
+			map _gather_objects($_, $relation), @$self
 		);
 	}
 	
@@ -67,7 +67,7 @@ sub _gather_objects
 sub gather_objects
 {
 	local %seen;
-	grep ref, _gather_objects(@_);
+	grep defined, _gather_objects(@_);
 }
 
 1;
